# valo_api_official

<div align="center">

[![Build status](https://github.com/raimannma/ValorantAPIOfficial/workflows/build/badge.svg?branch=master&event=push)](https://github.com/raimannma/ValorantAPIOfficial/actions?query=workflow%3Abuild)
[![Python Version](https://img.shields.io/pypi/pyversions/valo_api_official.svg)](https://pypi.org/project/valo_api_official/)
[![Dependencies Status](https://img.shields.io/badge/dependencies-up%20to%20date-brightgreen.svg)](https://github.com/raimannma/ValorantAPI/pulls?utf8=%E2%9C%93&q=is%3Apr%20author%3Aapp%2Fdependabot)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Security: bandit](https://img.shields.io/badge/security-bandit-green.svg)](https://github.com/PyCQA/bandit)
[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/raimannma/ValorantAPIOfficial/blob/master/.pre-commit-config.yaml)
[![Semantic Versions](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--versions-e10079.svg)](https://github.com/raimannma/ValorantAPIOfficial/releases)
[![License](https://img.shields.io/github/license/raimannma/ValorantAPIOfficial)](https://github.com/raimannma/ValorantAPIOfficial/blob/master/LICENSE)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/3b23d2a3b1694356bc95255a2edb83e6)](https://www.codacy.com/gh/raimannma/ValorantAPIOfficial/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=raimannma/ValorantAPIOfficial&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/3b23d2a3b1694356bc95255a2edb83e6)](https://www.codacy.com/gh/raimannma/ValorantAPIOfficial/dashboard?utm_source=github.com&utm_medium=referral&utm_content=raimannma/ValorantAPIOfficial&utm_campaign=Badge_Coverage)
[![Downloads](https://pepy.tech/badge/valo-api-official)](https://pepy.tech/project/valo-api-official)

Valorant API Wrapper

</div>

## Installation

    pip install valo-api-official

## Documentation

### Hosted

The documentation is hosted here: https://raimannma.github.io/ValorantAPIOfficial/

### From Source

After installing the package dependencies `pip install -r requirements.txt`, you can use the following commands to get the documentation:

    cd docs/ && make html

Open the index.html file in the docs/_build/html/ directory.
